# Shiny Tutorial
# Dean Young - Chester Ismay
# Reed College Paideia 2k16
# For use with "Shiny Interactive Data Analysis"
# Original credit to Garrett Grolemond

library(shiny) #loads the shiny package

set.seed(76)
vec <- rnorm(100000)
# The ui object determines the APPEARANCE of your shinny app but does not actually do any "work". 
# That is the job of the server object below.
ui <- fluidPage(
  sliderInput(inputId = "num", 
    label = "Choose a number", 
    value = 25, min = 1, max = 100),
  plotOutput("hist")# create a plot (reserves space but still requires an actual plot to be generated by the server object)

)

# The server object sends the inputs to the correct ouputs for the ui object to display in the shiny app.  
# Note that the histogram generated by the hist() function requires a "breaks" argument which determines how to bin
# the data for the histogram. We have set that argument to be evaluated as input$n_breaks which links the argument
# to the input "n_breaks" in the ui object. The same concept is used for the density plot.
server <- function(input, output) {
  output$hist <- renderPlot({
    hist(vec, breaks = input$num)
  })
}

# Runs your app. The function shinyApp(ui,server) requires two arguments: the ui object and the server object.
shinyApp(ui = ui, server = server)

# Exercise: Can you add an input that allows the shiny app user to fill the histogram bars with their own chosen color? 
# Hint: the hist() function has a "col='INSERT COLOR HERE'" argument. Type "?hist()" for more info.
# Hint 2: the selectInput() function takes three arguments selectInput(inputId = "???",label="???",choices=list("???","???","???"))